pub fn workspace_root(env_var: &str) -> PathBuf
Find the workspace root by checking an explicit env var, CARGO_MANIFEST_DIR, then walking up from cwd.
CARGO_MANIFEST_DIR
Panics when the process working directory cannot be determined.